package
Version:
v0.0.0-...-fc28805
Opens a new window with list of versions in this module.
Published: Nov 29, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Logger interface {
Info(msg string, keysAndValues ...interface{})
Error(msg string, keysAndValues ...interface{})
Debug(msg string, keysAndValues ...interface{})
Fatal(msg string, keysAndValues ...interface{})
}
Logger interface
New creates a new logger instance
Source Files
¶
Click to show internal directories.
Click to hide internal directories.